@@ -582,8 +582,12 @@ SDL_Surface * SDL_SetVideoMode (int width, int height, int bpp, Uint32 flags)
 	SDL_GrabMode saved_grab;
 
 	if( bpp > 16 ) {
-		SDL_SetError("Maximum supported bitdepth is 16");
-		return(NULL);
+		if( flags & SDL_ANYFORMAT ) {
+			bpp = 0;
+		} else {
+			SDL_SetError("Maximum supported bitdepth is 16");
+			return(NULL);
+		}
 	}
 
 	/* Start up the video driver, if necessary..
